@@ -25,7 +25,7 @@ runtest() {
 	echo Testing source: >> "$CFGLOG"
 	cat checkenv.cc >> "$CFGLOG"
 	echo Testing call:  "$CXX -c -o checkenv.o checkenv.cc $@ 2>>$CFGLOG" >> "$CFGLOG"
-	if eval '$CXX -c -o checkenv.o checkenv.cc "$@" 2>>$CFGLOG' ; then
+	if eval '$CXX -o checkenv_testbin checkenv.cc "$@" 2>>$CFGLOG' ; then
 		echo "$result"
 	fi
 }
@@ -34,12 +34,11 @@ rm -f checksuf.cc checksuf checksuf.exe
 
 echo 'int main() {return 0;}' > checkenv.cc
 "$CXX" -o checksuf checkenv.cc
+EXEPRE='./'
 if test -e checksuf.exe; then
    EXESUF=.exe
-   EXEPRE=''
 elif test -e checksuf ; then
    EXESUF=''
-   EXEPRE='./'
 else
    echo "Compiler didn't create binary, cannot continue" >&2
 fi
@@ -66,10 +65,22 @@ int main() { return NULL != boost::shared_ptr<int>(new int(1)); }
 runtest HAVE_BOOST_SMARTPTR "$@"
 
 echo '#include <wordexp.h>
+    int main(int argc, char **argv)
+       {
+          wordexp_t p;
+          return wordexp(argv[0], &p, 0);
+
+       }
 ' > checkenv.cc
 runtest HAVE_WORDEXP "$@"
 
 echo '#include <glob.h>
+    int main(int argc, char **argv)
+       {
+          glob_t p;
+          return glob(argv[0], 0, 0, &p);
+
+       }
 ' > checkenv.cc
 runtest HAVE_GLOB "$@"
 
@@ -77,10 +88,11 @@ echo '
        #define _XOPEN_SOURCE 600
        #include <fcntl.h>
 
-       int testme(int fd, off_t offset, off_t len, int advice)
+       int testme(int fd, off_t offset, off_t len, int)
        {
-          return posix_fadvise(fd, offset, len, advice);
+          return posix_fadvise(fd, offset, len, POSIX_FADV_SEQUENTIAL);
        }
+       int main(int,char**){return testme(0,0,0,0);}
 ' > checkenv.cc
 runtest HAVE_FADVISE "$@"
 
@@ -88,16 +100,11 @@ echo '
 #include <sys/mman.h>
 int testme(void *addr, size_t length, int advice) {
    return posix_madvise(addr, length, advice);
-}' > checkenv.cc
-runtest HAVE_MADVISE "$@"
+}
+int main(int,char**){return testme(0,0,0);}
 
-echo '
-#define _XOPEN_SOURCE 600
-#include <fcntl.h>
-int testme(int fd, off_t offset, off_t len) {
-   return posix_fallocate(fd, offset, len);
-}' > checkenv.cc
-runtest HAVE_POSIX_FALLOCATE "$@"
+' > checkenv.cc
+runtest HAVE_MADVISE "$@"
 
 echo '
 #define _GNU_SOURCE
@@ -112,10 +119,10 @@ int main()
 runtest HAVE_LINUX_FALLOCATE "$@"
 
 echo '#include <sys/sendfile.h>
-ssize_t testme()
+int main(int argc, char **argv)
 {
    off_t yes(3);
-   return sendfile(1, 2, &yes, 4);
+   return (int) sendfile(1, 2, &yes, 4);
 }
 ' > checkenv.cc
 runtest HAVE_LINUX_SENDFILE "$@"
@@ -162,5 +169,24 @@ else
 fi
 
 
+if test "$SIZEOF_INT" ; then
+    echo "#define SIZEOF_INT $SIZEOF_INT"
+else
+    echo '
+    #include <stdio.h>
+    int main()
+    {
+        printf("#define SIZEOF_INT %u", sizeof(int));
+        return 0;
+    }
+    ' > checkenv.cc
+    echo Testing call:  "$CXX -o getlongsize checkenv.cc $@ 2>>$CFGLOG" >> "$CFGLOG"
+    rm -f getlongsize
+    rm -f getlongsize.exe
+    $CXX -o getlongsize checkenv.cc "$@" 2>>$CFGLOG
+    ${EXEPRE}getlongsize${EXESUF}
+    echo
+fi
+
 
 exit 0
