@@ -1,7 +1,13 @@
 #!/usr/bin/perl
 #
-open(fdd, ">conf/deb_mirrors") || die;
-open(fdv, ">conf/debvol_mirrors") || die;
+
+use strict;
+my %fddset;
+my %fdvset;
+# temp values within one data set
+my @hosts;
+my @pathsdeb;
+my @pathsvol;
 
 while(<>)
 {
@@ -11,9 +17,8 @@ while(<>)
    next if /^#/;
    if(/(\S+)\s*:\s*(\S+)/)
    {
-      $key=$1;
-      $value=$2;
-      #print "moo, $key -> $val\n";
+      my $key=$1;
+      my $value=$2;
 
       if($key eq "Site" || $key eq "Alias" || $key eq "Includes" || $key eq "Aliases")
       {
@@ -30,16 +35,10 @@ while(<>)
    }
    elsif(@hosts)
    {
-      foreach $h (@hosts)
+      foreach my $h (@hosts)
       {
-         foreach $pd (@pathsdeb)
-         {
-            print fdd "http://$h$pd\n";
-         }
-         foreach $pd (@pathsvol)
-         {
-            print fdv "http://$h$pd\n";
-         }
+         $fddset{"$h$_"}=1 foreach @pathsdeb;
+         $fdvset{"$h$_"}=1 foreach @pathsvol;
       }
       undef @hosts;
       undef @pathsdeb;
@@ -48,5 +47,11 @@ while(<>)
 
 }
 
+open(fdd, ">conf/deb_mirrors") || die;
+open(fdv, ">conf/debvol_mirrors") || die;
+print fdd "http://$_\n" foreach(sort(keys %fddset));
+print fdv "http://$_\n" foreach(sort(keys %fdvset));
 close(fdd) || die;
+print "conf/deb_mirrors created\n";
 close(fdv) || die;
+print "conf/debvol_mirrors created\n";
