@@ -10,12 +10,12 @@ a=0
 for x in `cat $src` ; do
    x=$(echo $x | sed -e 's,/\+,/,g ; s,http:/,http://, ; s,/$,,')
    a=$(( $a + 1 ))
-   wget -q -t 1 -O- --timeout=10 $x/dists/ | grep -q 'updates\|security\|backports\|feisty\|gutsy\|hardy\|intrepid' && echo $x > $wd/url.$a &
+   wget -q -t 1 -O- --timeout=10 $x/dists/ | grep -q 'updates\|security\|backports\|feisty\|gutsy\|hardy\|intrepid\|jaunty\|karmic\|lucid\|maverick\|depper' && echo $x > $wd/url.$a &
    sleep 0.2
 done
 
 wait
 
-cat $wd/url.* | sed -e 's,$,/,;s,//$,/,' > $listfile
+cat $wd/url.* | sed -e 's,$,/,;s,//$,/,' | sort -u > $listfile
 
 echo $listfile created.
