@@ -12,10 +12,8 @@
 #include "header.h"
 #include "caddrinfo.h"
 #include "sockio.h"
-#include "rechecks.h"
 #include "acbuf.h"
 #include "acfg.h"
-#include "acfg_defaults.h"
 #include "lockable.h"
 
 #include <sys/types.h>
@@ -106,10 +104,9 @@ public:
 		_cerr("Act done, result: "<<res<<endl);
 		if(!res)
 			return res;
-		rechecks rex;
-		rechecks::eFileKind type=rex.getFiletype(path);
+		rechecks::eFileKind type=rechecks::GetFiletype(path);
 		_cerr ( "type: " << type );
-		if (type!=rex.FILE_INDEX) // not caching volatile stuff
+		if (type!=rechecks::FILE_INDEX) // not caching volatile stuff
 		{
 			lockguard g(mxCache);
 			cache[path]=seen_length;
@@ -320,10 +317,9 @@ bool GetFstat(const char *path, struct stat *stbuf, tDlDesc *d=NULL)
 
 	// assume that everything downloadable is a file and a directory is 404
 
-	rechecks rex;
-	rechecks::eFileKind type=rex.getFiletype(path);
+	rechecks::eFileKind type=rechecks::GetFiletype(path);
 	_cerr ( "type: " << type );
-	if (type==rex.FILE_PKG || type==rex.FILE_INDEX)
+	if (type==rechecks::FILE_PKG || type==rechecks::FILE_INDEX)
 	{
 		//ldbg("Is a file!");
 		stbuf->st_mode |= S_IFREG;
