@@ -5,19 +5,20 @@
 #include "config.h"
 #include "meta.h"
 
-#define ACVERSION "0.4.6"
-
 class hostdata;
 
+static const int RESERVED_DEFVAL = -4223;
+
 namespace acfg
 {
 
 extern MYSTD::string cachedir, logdir, confdir, fifopath, user, group, pidfile, 
-reportpage, vfilepat, pfilepat, wfilepat, agentname, remoteport, adminauth, bindaddr, port, sUmask;
+reportpage, vfilepat, pfilepat, wfilepat, agentname, remoteport, adminauth, bindaddr, port, sUmask,
+dontcacherq, dontcachetgt, dontcache;
 
 extern int debug, offlinemode, foreground, verbose, stupidfs, forcemanaged, 
 verboselog, extreshhold, exfailabort, tpstandbymax, tpthreadmax, dnscachetime, dlbufsize,
-exporigin, logxff, oldupdate, recompbz2, nettimeout, updinterval, forwardsoap;
+exporigin, logxff, oldupdate, recompbz2, nettimeout, updinterval, forwardsoap, dirperms, fileperms;
 
 extern tHttpUrl proxy_info;
 
@@ -38,4 +39,17 @@ tHostiVec * GetBackendVec(const MYSTD::string * vname);
 
 }
 
+namespace rechecks
+{
+typedef enum {
+	FILE_PKG,
+	FILE_INDEX,
+	FILE_INVALID
+} eFileKind;
+eFileKind GetFiletype(const MYSTD::string &);
+bool MatchWhitelist(const MYSTD::string &);
+bool MatchUncacheableRequest(const MYSTD::string &);
+bool MatchUncacheableTarget(const MYSTD::string &);
+}
+
 #endif
