@@ -9,6 +9,7 @@
 #define BGTASK_H_
 
 #include "maintenance.h"
+#include <stdio.h>
 
 class bgtask : public maintenance
 {
@@ -32,7 +33,14 @@ protected:
 
 
 	/// pass it to the base class but store a copy to a file
-	virtual void SendMsg(const MYSTD::string &x);
+
+	virtual void SendChunk(const char *data, size_t len);
+	/*
+	 * In theory, it shouldn't be necessary because there is base
+	 * implementation which is virtual... but for some STUPID REASON
+	 * the compiler goes nuts and refuses to consider using it
+	 * */
+	void SendChunk(const MYSTD::string &x) { SendChunk(x.c_str(), x.size()); }
 
 	void DumpLog(time_t id);
 
