@@ -28,6 +28,8 @@
 #define AI_ADDRCONFIG 0
 #endif
 
+class CAddrInfo;
+
 class CAddrInfo {
 public:
 	time_t m_nResTime;
@@ -36,16 +38,20 @@ public:
 	CAddrInfo();
 	bool Resolve(const MYSTD::string & sHostname, const MYSTD::string &sPort, MYSTD::string & sErrorBuf);
 	~CAddrInfo();
+
+	typedef SHARED_PTR<CAddrInfo> SPtr;
+	static SPtr CachedResolve(const MYSTD::string & sHostname, const MYSTD::string &sPort,
+			MYSTD::string &sErrorMsgBuf);
+
 protected:
 	struct addrinfo * m_resolvedInfo; // getaddrinfo excrements, to cleanup
+
 private:
 	// not to be copied ever
 	CAddrInfo(const CAddrInfo&);
 	CAddrInfo operator=(const CAddrInfo&);
+
 };
 
-typedef SHARED_PTR<CAddrInfo> CAddrInfoPtr;
-CAddrInfoPtr _Resolve(const MYSTD::string & sHostname, const MYSTD::string &sPort, 
-		MYSTD::string &sErrorMsgBuf);
 
 #endif /*CADDRINFO_H_*/
