@@ -4,7 +4,11 @@
 
 #include "../acsyscap.h"
 
-#define CREATPERMS 00664
+#define ACVERSION "0.5.1"
+
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
+
 
 // keep this consistently, for experiments with other STL implementations
 #define MYSTD std
@@ -29,6 +33,9 @@
 #warning LibBz2 or its development files are not available. Install them (e.g. libbz2-dev) and run "make clean". Bzip2 format support disabled.
 #endif
 
+// make off_t be a 64 bit type
+// added in Makefile... #define _FILE_OFFSET_BITS 64
+
 #define SHARED_PTR SMARTPTR_SPACE::shared_ptr
 #define INTRUSIVE_PTR SMARTPTR_SPACE::intrusive_ptr
 #define WEAK_PTR SMARTPTR_SPACE::weak_ptr
@@ -42,8 +49,6 @@
 #define MYCATCH catch
 #endif
 
-#define __STDC_FORMAT_MACROS
-#include <inttypes.h>
 
 #define ENEMIESOFDOSFS "?[]\\=+<>:;#"
 
