@@ -4,7 +4,6 @@
 
 #include "config.h"
 #include "lockable.h"
-#include "rechecks.h"
 
 #include <list>
 #include <string>
@@ -60,7 +59,6 @@ class con {
       friend class job;
       bool SetupDownloader(const char *xff);
       dlcon * m_pDlClient;
-      rechecks rex;
       MYSTD::string m_sClientHost;
       header *m_pTmpHead;
       
