@@ -13,12 +13,12 @@
 class IFileHandler
 {
 public:
-	virtual void ProcessRegular(const MYSTD::string &sPath, const struct stat &) =0;
-	virtual void ProcessOthers(const MYSTD::string &sPath, const struct stat &)=0;
+	virtual bool ProcessRegular(const MYSTD::string &sPath, const struct stat &) =0;
+	virtual bool ProcessOthers(const MYSTD::string &sPath, const struct stat &)=0;
 	virtual ~IFileHandler() {};
 };
 
-void DirectoryWalk(MYSTD::string & sRootDir, IFileHandler *h);
+bool DirectoryWalk(MYSTD::string & sRootDir, IFileHandler *h);
 
 
 
