@@ -4,7 +4,6 @@
 #include "config.h"
 #include "meta.h"
 #include "dirwalk.h"
-#include "rechecks.h"
 #include "maintenance.h"
 #include "lockable.h"
 #include "csmapping.h"
@@ -83,7 +82,6 @@ protected:
 	// File handler
 	time_t m_nTimeNow;
 	tStrPos m_nDropPrefLen;
-	rechecksEx m_rex;
 
 	bool m_bErrAbort, m_bVerbose, m_bForceDownload;
 	bool m_bScanInternals, m_bByPath, m_bByChecksum, m_bSkipHeaderChecks;
