@@ -9,7 +9,6 @@
 #include <header.h>
 
 // Life line (process states) of a file description item
-typedef unsigned int FiStatus;
 #define FIST_FRESH 		0
 #define FIST_INITED		1
 #define FIST_DLPENDING		4
@@ -29,13 +28,15 @@ class fileitem : public condition
 
 public:
 	
-	~fileitem();
+	virtual ~fileitem();
 	
 	// initialize file item, return the status
 	FiStatus Setup(bool bDynType, bool bIgnoreCached=false);
 	
-	int GetFileFd();
+	virtual int GetFileFd();
 	uint64_t GetTransferCount();
+	// send helper like wrapper for sendfile. Just declare virtual here to make it better customizable later.
+	virtual ssize_t SendData(int confd, int filefd, off_t &nSendPos, size_t nMax2SendNow);
 	
 	// downloader instruments
 	
@@ -48,33 +49,36 @@ public:
 	/*!
 	 * \return true IFF ok and caller might continue. False -> caller should abort.
 	 */
-	bool StoreFileData(const char *data, unsigned int size);
+	virtual bool StoreFileData(const char *data, unsigned int size);
 	header const * GetHeaderUnlocked();
 	
 	FiStatus GetStatus() { setLockGuard; return status; }
-	FiStatus GetStatusUnlocked() { return status; }
+	FiStatus GetStatusUnlocked(off_t &nGoodDataSize) { nGoodDataSize = m_nSizeChecked; return status; }
 	
 	bool m_bCheckFreshness;
 
 	uint64_t m_nIncommingCount;
-	off_t m_nSizeChecked, m_nSizeSeen;
+	off_t m_nSizeSeen;
 	MYSTD::string m_sPath, m_sKey;
 	
 protected:
-	int m_filefd;
+	fileitem(MYSTD::string);
+	off_t m_nSizeChecked;
 	header m_head;
+	int m_filefd;
 	int m_nDlRefsCount;
 	FiStatus status;
-	
-private:
-	friend tFileItemPtr GetFileItem(MYSTD::string sPath);
-	fileitem(MYSTD::string);
 
+	bool m_bAllowStoreData;
+
+
+	////////////////////////////////
+	// Item pool management methods
+	////////////////////////////////
 public:
-
 	// public constructor wrapper, get a unique object from the map
 	static tFileItemPtr GetFileItem(MYSTD::string sPath); // also opens the cached file and increases reference count
-	static void DelUser(MYSTD::string sPath); // decrease dependent user count
+	virtual void Unreg(); // decrease dependent user count
 };
 
 extern lockable mapLck;
