@@ -16,12 +16,10 @@ class job {
 
    public:
 
-	   typedef enum {
-	   	R_DONE=0,
-	   	R_AGAIN=1,
-	   	R_DISCON=2,
-	   	R_NOTFORUS=3
-	   } eJobResult;
+	   typedef enum
+	{
+		R_UNDEFINED = -1, R_DONE = 0, R_AGAIN = 1, R_DISCON = 2, R_NOTFORUS = 3
+	} eJobResult;
 
 	   typedef enum {
 	   	STATE_FRESH,
@@ -75,13 +73,14 @@ class job {
       off_t m_nSendPos, m_nRangeLast;
       off_t m_nAllDataCount;
       
-      long m_nCachedMaxSize;
-      
       unsigned int m_nChunkRemainingBytes;
       USHORT m_type; // file type, bit mask
       
       job(const job&);
       job & operator=(const job&);
+
+      eJobResult BuildAndEnqueHeader(const char * &szErrRet, const FiStatus &fistate, const off_t &nGooddataSize);
+      FiStatus _SwitchToPtItem(const MYSTD::string &fileLoc);
 };
 
 #endif
