@@ -17,13 +17,13 @@ public:
 
 protected:
 	
-	virtual void SendMsg(const MYSTD::string &x);
-	virtual void SendMsg(const char *data, size_t size);
-	bool _SendHelper(const char *data, size_t len, int flags);
+	virtual void SendChunk(const MYSTD::string &x);
+	virtual void SendChunk(const char *data, size_t size);
+	bool SendRawData(const char *data, size_t len, int flags);
 	virtual void EndTransfer();
 	MYSTD::string & GetHostname();
-	
-	void SendDecoration(bool bBegin, const char *httpcode="200", const char *szDecoFile=NULL);
+	//void SendDecoration(bool bBegin, const char *szDecoFile=NULL);
+	void SendChunkedPageHeader(const char *httpcode=NULL, const char *mimetype=NULL);
 	void SetStyle(MYSTD::string&);
 	int m_reportFD;
 	const char *m_szDecoFile;
