@@ -4,7 +4,7 @@
 //! Reuses lots of processing code
 #include "expiration.h"
 
-#include <sys/stat.h>
+#include "fileio.h"
 #include <time.h>
 #include <string.h>
 #include "csmapping.h"
