@@ -3,14 +3,14 @@
 
 #include "meta.h"
 
-#ifndef NO_TCP_TUNNING
+#include <netinet/in.h>
 #include <netinet/tcp.h>
-#endif
 #include <pthread.h>
-#include <errno.h>
+
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/un.h>
 #include <netdb.h>
 
 using namespace MYSTD;
@@ -27,4 +27,8 @@ using namespace MYSTD;
 #define MSG_NOSIGNAL 0
 #endif
 
+#ifndef MSG_MORE
+#define MSG_MORE 0
+#endif
+
 #endif /*SOCKIO_H_*/
