@@ -2,44 +2,42 @@
 
 #define LOCAL_DEBUG
 #include "debug.h"
-// doesn't work here without logging, always ignore
-#ifdef ldbg
-#undef ldbg
-#endif
 
 #include "acfg.h"
+#include "meta.h"
 #include "filereader.h"
-#include "rechecks.h"
-
-#ifdef HAVE_WORDEXP
-#include <wordexp.h>
-#elif defined(HAVE_GLOB)
-#include <glob.h>
-#endif
 
 #include <errno.h>
+#include <regex.h>
+
 
 #include <iostream>
 #include <fstream>
 #include <string>
-#include <meta.h>
 #include <list>
 #include <map>
 #include <algorithm>
 
-#include "acfg_defaults.h"
-
 using namespace MYSTD;
 
+namespace rechecks
+{
+bool CompileExpressions();
+bool CompileUncExpressions(const string & req, const string & tgt);
+}
+
+
 namespace acfg {
 
 // internal stuff:
 char alphabet[65] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 string sPopularPath("/debian/");
 
+string dontcache, proxy, dontcacherq, dontcachetgt;
+
 MapNameToString n2sTbl[] = {
 		{  "Port", 			&port , 0}
-		,{  "CacheDir", 	&cachedir, 0 }
+		,{ "CacheDir", 	&cachedir, 0 }
 		,{ "LogDir", 	&logdir , 0}
 		,{ "SocketPath", 	&fifopath, 0}
 		,{ "PidFile", 	&pidfile, 0}
@@ -51,31 +49,36 @@ MapNameToString n2sTbl[] = {
 		,{ "AdminAuth",  &adminauth, 0}
 		,{ "BindAddress", &bindaddr, 0}
 		,{ "UserAgent", &agentname, 0}
-		//,{ "Umask",		  &sUmask}
+		,{ "DontCache",	&dontcache, 0}
+		,{ "DontCacheRequested",	&dontcachetgt, 0}
+		,{ "DontCacheResolved",	&dontcacherq, 0}
 };
 
 MapNameToInt n2iTbl[] = {
-		{ "Debug", 		&debug, 0 }
-		,{ "OfflineMode", 	&offlinemode , 0}
-		,{ "ForeGround", 	&foreground , 0}
-		,{ "Verbose", 		0, "Option is deprecated, ignoring the value." }
-		,{ "ForceManaged", 	&forcemanaged , 0}
-		,{ "StupidFs", 		&stupidfs , 0}
-		,{ "VerboseLog",	&verboselog , 0}
-		,{ "ExTreshold",	&extreshhold, 0}
-		,{ "MaxSpareThreadSets",	&tpstandbymax, "Deprecated option name, mapped to MaxStandbyConThreads"}
-		,{ "MaxStandbyConThreads",	&tpstandbymax, 0}
-		,{ "MaxConThreads",	&tpthreadmax, 0}
-		,{ "DnsCacheSeconds", &dnscachetime, 0}
-		,{ "UnbufferLogs", &debug , 0}
-		,{ "ExAbortOnProblems", &exfailabort, 0}
-		,{ "ExposeOrigin", &exporigin, 0}
-		,{ "LogSubmittedOrigin", &logxff, 0}
-		,{ "OldIndexUpdater", &oldupdate, "Option is deprecated, ignoring the value." }
-		,{ "RecompBz2", &recompbz2, 0}
-		,{ "NetworkTimeout", &nettimeout, 0}
-		,{ "MinUpdateInterval", &updinterval, 0}
-		,{ "ForwardBtsSoap", &forwardsoap, 0}
+		{ "Debug", 		&debug, 0 , 10}
+		,{ "OfflineMode", 	&offlinemode , 0, 10}
+		,{ "ForeGround", 	&foreground , 0, 10}
+		,{ "Verbose", 		0, "Option is deprecated, ignoring the value." , 10}
+		,{ "ForceManaged", 	&forcemanaged , 0, 10}
+		,{ "StupidFs", 		&stupidfs , 0, 10}
+		,{ "VerboseLog",	&verboselog , 0, 10}
+		,{ "ExTreshold",	&extreshhold, 0, 10}
+		,{ "MaxSpareThreadSets",	&tpstandbymax, "Deprecated option name, mapped to MaxStandbyConThreads", 10}
+		,{ "MaxStandbyConThreads",	&tpstandbymax, 0, 10}
+		,{ "MaxConThreads",	&tpthreadmax, 0, 10}
+		,{ "DnsCacheSeconds", &dnscachetime, 0, 10}
+		,{ "UnbufferLogs", &debug , 0, 10}
+		,{ "ExAbortOnProblems", &exfailabort, 0, 10}
+		,{ "ExposeOrigin", &exporigin, 0, 10}
+		,{ "LogSubmittedOrigin", &logxff, 0, 10}
+		,{ "OldIndexUpdater", &oldupdate, "Option is deprecated, ignoring the value." , 10}
+		,{ "RecompBz2", &recompbz2, 0, 10}
+		,{ "NetworkTimeout", &nettimeout, 0, 10}
+		,{ "MinUpdateInterval", &updinterval, 0, 10}
+		,{ "ForwardBtsSoap", &forwardsoap, 0, 10}
+
+		,{ "DirPerms", &dirperms, 0, 8}
+		,{ "FilePerms", &fileperms, 0, 8}
 };
 
 #define _iterPos(it, start) (it-start.begin())/sizeof(it)
@@ -108,21 +111,21 @@ string * _GetStringPtr(const string &key)  {
 		if(0==strcasecmp(key.c_str(), n2sTbl[i].name))
 		{
 			if(n2sTbl[i].warn)
-				cerr << "Warning, " << key << ": " << n2sTbl[i].warn << endl; 
-						
+				cerr << "Warning, " << key << ": " << n2sTbl[i].warn << endl;
+
 			return n2sTbl[i].ptr;
 		}
 	}
 	return NULL;
 }
 
-int * _GetIntPtr(const string &key)  {
+int * _GetIntPtr(const string &key, int &base)  {
 	for(unsigned int i=0; i<_countof(n2iTbl); i++) {
 		if(0==strcasecmp(key.c_str(), n2iTbl[i].name))
 		{
 			if(n2iTbl[i].warn)
 				cerr << "Warning, " << key << ": " << n2iTbl[i].warn << endl;
-			
+			base = n2iTbl[i].base;
 			return n2iTbl[i].ptr;
 		}
 	}
@@ -139,7 +142,7 @@ inline void _FixPostPreSlashes(string &val)
 		val.insert(0, "/", 1);
 }
 
-bool _ReadMainConfiguration(const char * szFilename)
+inline bool _ReadMainConfiguration(const string & szFilename)
 {
 	filereader reader;
 	reader.OpenFile(szFilename);
@@ -150,6 +153,9 @@ bool _ReadMainConfiguration(const char * szFilename)
 		bNotEof=reader.GetOneLine(sLine);
 		if (IsValidButIrrelevantLine(sLine))
 			continue;
+#ifdef DEBUG
+		cerr << sLine <<endl;
+#endif
 		if(! SetOption(sLine))
 			BARF("Error reading main options, terminating.");
 		// XXX: move that to SetOption... if (debug>4)
@@ -200,29 +206,7 @@ inline void _AddRemapInfo(bool bAsBackend, const string & token,
 		if (sPath[0]!=cPathSep)
 			sPath.insert(0, confdir+sPathSep);
 		
-		tStrVec srcs;
-
-#ifdef HAVE_WORDEXP
-		wordexp_t p;
-		memset(&p, 0, sizeof(p));
-		if(0==wordexp(sPath.c_str(), &p, 0))
-		{
-			for (UINT i=0; i<p.we_wordc; i++)
-				srcs.push_back(p.we_wordv[i]);
-			wordfree(&p);
-		}
-		
-#elif defined HAVE_GLOB
-		glob_t globbuf;
-		memset(&globbuf, 0, sizeof(glob_t));
-		if(0==glob(sPath.c_str(), GLOB_DOOFFS | GLOB_NOSORT, NULL, &globbuf))
-		{
-			for (UINT i=0; i<globbuf.gl_pathc; i++)
-				srcs.push_back(globbuf.gl_pathv[i]);
-			globfree(&globbuf);
-		}
-#endif
-		std::sort(srcs.begin(), srcs.end());
+		tStrVec srcs=ExpandFilePattern(sPath, true);
 		for(tStrVecIterConst it=srcs.begin(); it!=srcs.end(); it++)
 		{
 			if (bAsBackend)
@@ -235,15 +219,22 @@ inline void _AddRemapInfo(bool bAsBackend, const string & token,
 
 bool SetOption(const MYSTD::string &sLine, bool bQuiet)
 {
-	string::size_type pos = sLine.find(":");
-	if (pos==stmiss)
-		pos = sLine.find("=");
-	if (pos==stmiss)
+	string::size_type posCol = sLine.find(":");
+	string::size_type posEq = sLine.find("=");
+	if (posEq==stmiss && posCol==stmiss)
 	{
 		if(!bQuiet)
 			cerr << "Not a valid configuration directive: " << sLine <<endl;
 		return false;
 	}
+	string::size_type pos;
+	if (posEq!=stmiss && posCol!=stmiss)
+		pos=min(posEq,posCol);
+	else if (posEq!=stmiss)
+		pos=posEq;
+	else
+		pos=posCol;
+
 	string key=sLine.substr(0, pos);
 	string value=sLine.substr(pos+1);
 	trimString(key);
@@ -253,9 +244,11 @@ bool SetOption(const MYSTD::string &sLine, bool bQuiet)
 	
 	string * psTarget;
 	int * pnTarget;
+	int nNumBase(10);
+
 	if ( NULL != (psTarget = _GetStringPtr(key)))
 		*psTarget=value;
-	else if ( NULL != (pnTarget = _GetIntPtr(key)))
+	else if ( NULL != (pnTarget = _GetIntPtr(key, nNumBase)))
 	{
 		const char *pStart=value.c_str();
 		if(! *pStart)
@@ -266,7 +259,7 @@ bool SetOption(const MYSTD::string &sLine, bool bQuiet)
 		
 		errno=0;
 		char *pEnd(0);
-		long nVal = strtol(pStart, &pEnd, 10);
+		long nVal = strtol(pStart, &pEnd, nNumBase);
 
 		if(RESERVED_DEFVAL == nVal)
 		{
@@ -309,6 +302,8 @@ bool SetOption(const MYSTD::string &sLine, bool bQuiet)
 				bIsBackend=true;
 				continue;
 			}
+			if(startsWithSz(tokens[i], "#"))
+				break;
 			_AddRemapInfo(bIsBackend, tokens[i], vname);
 		}
 		
@@ -369,23 +364,26 @@ tHostiVec * GetBackendVec(const string * vname)
 
 void _ReadBackendsFiles(const string & sFile, const string &sRepName)
 {
+
+	int nAddCount=0;
+	string sLine, key, val;
+	tHttpUrl entry;
+
 	filereader reader;
 	reader.OpenFile(sFile.c_str());
-	
+
 	if(debug>4)
 		cout << "Reading backend file: " << sFile <<endl;
 	if(!reader.CheckGoodState(false))
 	{
 		if(debug>4)
 			cout << "No backend data found, file ignored."<<endl;
-		return;
+		goto try_read_default;
 	}
 	
-	string sLine, key, val;
-	tHttpUrl entry;
 	
-	for(bool bNotEof=true;bNotEof;) {
-		
+	for(bool bNotEof=true;bNotEof;)
+	{
 		bNotEof=reader.GetOneLine(sLine);
 		//if(debug)
 		//	cerr << "backends, got line: " << sLine <<endl;
@@ -405,6 +403,7 @@ void _ReadBackendsFiles(const string & sFile, const string &sRepName)
 #endif		
 
 			mapRepName2Backends[sRepName].push_back(entry);
+			nAddCount++;
 			entry.clear();
 		}
 		else if(_ParseLine(sLine, key, val))
@@ -437,6 +436,14 @@ void _ReadBackendsFiles(const string & sFile, const string &sRepName)
 			exit(2);
 		}
 	}
+
+try_read_default:
+	if(nAddCount || endsWithSzAr(sFile, ".default"))
+		return;
+	if(debug>4)
+		cout << "Trying to read replacement from " << sFile << ".default" <<endl;
+	_ReadBackendsFiles(sFile+".default", sRepName);
+
 }
 
 void ShutDown()
@@ -495,11 +502,11 @@ void _ReadRewriteFiles(const string & sFile, const string & sRepName)
 						<< reader.GetPositionDescription() <<endl;
 				exit(2);
 			}
-			for (tStrVec::const_iterator itHost=hosts.begin(); 
+			for (tStrVecIterConst itHost=hosts.begin();
 			itHost!=hosts.end(); 
 			itHost++)
 			{
-				for (tStrVec::const_iterator itPath=paths.begin(); 
+				for (tStrVecIterConst itPath=paths.begin();
 				itPath!=paths.end(); 
 				itPath++)
 				{
@@ -545,24 +552,27 @@ void _ReadRewriteFiles(const string & sFile, const string & sRepName)
 	}
 }
 
+
+
 void ReadConfigDirectory(const char *szPath)
 {
 	// TODO: early abort when the dir does not exist!
 
 	char buf[PATH_MAX];
-	realpath(szPath, buf);
+	if(!realpath(szPath, buf))
+  {
+     cerr << "Failed to open config directory" << endl;
+     exit(42);
+  }
 	confdir=buf; // pickup the last config directory
 
-#ifdef HAVE_WORDEXP
-	wordexp_t p;
-    wordexp((confdir+"/*.conf").c_str(), &p, 0);
-    for (UINT i=0; i<p.we_wordc; i++)
-    	_ReadMainConfiguration(p.we_wordv[i]);
-    wordfree(&p);
+#if defined(HAVE_WORDEXP) || defined(HAVE_GLOB)
+	tStrVec srcs=ExpandFilePattern(confdir+SZPATHSEP"*.conf", true);
+	for(tStrVecIterConst it=srcs.begin(); it!=srcs.end(); it++)
+		_ReadMainConfiguration(*it);
 #else
-    _ReadMainConfiguration((confdir+cPathSep+"acng.conf").c_str());
+	_ReadMainConfiguration(confdir+SZPATHSEP"acng.conf");
 #endif
-
 }
 
 string _GetBase64Auth(const string & sUserColonPass)
@@ -618,6 +628,14 @@ void PostProcConfig()
 	if(stupidfs)
 		cerr << "Warning, support for primitive filesystems is not completely implemented!\n";
 	
+	// let's also apply the umask to the directory permissions
+	{
+		mode_t mask = umask(0);
+		umask(mask); // restore it...
+		dirperms &= ~mask;
+		fileperms &= ~mask;
+	}
+
     // postprocessing
 
 #ifdef FORCE_CUSTOM_UMASK
@@ -650,8 +668,7 @@ void PostProcConfig()
       exit(EXIT_FAILURE);
    }
    
-   rechecksEx rex;
-   if(rex.IsRegexOk())
+   if(!rechecks::CompileExpressions())
    {
 	   cerr << "An error occured while compiling file type regular expression!" <<endl;
 	   exit(EXIT_FAILURE);
@@ -726,6 +743,14 @@ void PostProcConfig()
    if(RESERVED_DEFVAL == forwardsoap)
 	   forwardsoap = !forcemanaged;
 
+
+   if(!rechecks::CompileUncExpressions(dontcachetgt.empty() ? dontcache : dontcachetgt,
+		   dontcacherq.empty() ? dontcache : dontcacherq))
+   {
+	   cerr << "An error occured while compiling regular expression for non-cached paths!" <<endl;
+	   exit(EXIT_FAILURE);
+   }
+
 #ifdef DEBUG
    if (acfg::debug>8)
 	{
@@ -765,6 +790,139 @@ void PostProcConfig()
 }
 }
 
+namespace rechecks
+{
+regex_t reIfiles, rePfiles, reWfiles;
+MYSTD::vector<regex_t> vecReqPatters, vecTgtPatterns;
+
+bool CompileExpressions()
+{
+	//printf("%s\\n%s\\n", a, b);
+
+    if(regcomp(&rePfiles, acfg::pfilepat.c_str(), REG_EXTENDED))
+    	return false;
+    if(regcomp(&reIfiles, acfg::vfilepat.c_str(), REG_EXTENDED))
+    	return false;
+    if(regcomp(&reWfiles, acfg::wfilepat.c_str(), REG_EXTENDED))
+    	return false;
+
+    return true;
+}
+
+eFileKind GetFiletype(const MYSTD::string & in) {
+	LOGSTART("rechecks::getFiletype");
+    dbgline;
+    if(!regexec(&rePfiles, in.c_str(), 0, NULL, 0))
+        return FILE_PKG;
+    dbgline;
+    if(!regexec(&reIfiles, in.c_str(), 0, NULL, 0))
+        return FILE_INDEX;
+    dbgline;
+    return FILE_INVALID;
+}
+
+bool MatchWhitelist(const MYSTD::string & in)
+{
+	return !regexec(&reWfiles, in.c_str(), 0, NULL, 0);
+}
+
+inline bool CompileUncachedRex(const MYSTD::string & token, bool bIsTgtPattern, bool bRecursiveCall)
+{
+	MYSTD::vector<regex_t> & patvec = bIsTgtPattern ? vecTgtPatterns : vecReqPatters;
+
+	if (0!=token.compare(0, 5, "file:")) // pure pattern
+	{
+		UINT pos = patvec.size();
+		patvec.resize(pos+1);
+		return 0==regcomp(&patvec[pos], token.c_str(), REG_EXTENDED);
+	}
+	else if(!bRecursiveCall) // don't go further than one level
+	{
+		string sPath=token.substr(5);
+		if (sPath.empty())
+			BARF("Bad file spec for repname, file:?");
+
+		if (sPath[0]!=cPathSep)
+			sPath.insert(0, acfg::confdir+sPathSep);
+
+		tStrVec srcs = ExpandFilePattern(sPath, true);
+		for(tStrVecIterConst it=srcs.begin(); it!=srcs.end(); it++)
+		{
+			filereader reader;
+			if(!reader.OpenFile(*it))
+			{
+				cerr << "Error opening pattern file: " << *it <<endl;
+				return false;
+			}
+			string line;
+			while(reader.GetOneLine(line))
+			{
+				if(!CompileUncachedRex(*it, bIsTgtPattern, true))
+					return false;
+			}
+		}
+		return true;
+	}
+
+	cerr << token << " is not supported here" <<endl;
+	return false;
+}
+
+
+bool CompileUncExpressions(const MYSTD::string & req, const MYSTD::string & tgt)
+{
+	tStrVec pats;
+	Tokenize(req, SPACECHARS, pats, false);
+	/*
+	 *
+	 if(acfg::debug>10)
+			cerr << "req: " << req << ", tgt: " << tgt << ",#req: " << pats.size()<< endl;
+			*/
+	for (tStrVec::const_iterator it = pats.begin(); it != pats.end(); it++)
+		if (!CompileUncachedRex(*it, false, false))
+			return false;
+	Tokenize(tgt, SPACECHARS, pats, false);
+	for (tStrVec::const_iterator it = pats.begin(); it != pats.end(); it++)
+		if (!CompileUncachedRex(*it, true, false))
+			return false;
+	return true;
+}
+
+
+
+bool MatchUncacheableRequest(const MYSTD::string & in)
+{
+	LOGSTART2("MatchUncacheableRequest", in << " against " << vecReqPatters.size() << " patterns");
+	for(vector<regex_t>::const_iterator it=vecReqPatters.begin();
+			it!=vecReqPatters.end(); it++)
+	{
+		if(!regexec(& (*it), in.c_str(), 0, NULL, 0))
+			return true;
+	}
+	return false;
+}
+
+bool MatchUncacheableTarget(const MYSTD::string &in)
+{
+	for(vector<regex_t>::const_iterator it=vecTgtPatterns.begin();
+			it!=vecTgtPatterns.end(); it++)
+	{
+		if(!regexec(& (*it), in.c_str(), 0, NULL, 0))
+			return true;
+	}
+	return false;
+}
+
+}
+
+void mkbasedir(const MYSTD::string & path)
+{
+    for(UINT pos=0; pos<path.size(); pos=path.find("/", pos+1))
+    {
+        if(pos>0)
+            mkdir(path.substr(0,pos).c_str(), acfg::dirperms);
+    }
+}
 /*
 int main(int argc, char **argv)
 {
