@@ -12,6 +12,7 @@
 #include <iostream>
 using namespace MYSTD;
 
+#include <cstdio>
 #include <cstring>
 #include <sys/time.h>
 #include <signal.h>
@@ -83,7 +84,6 @@ int main(int argc, char **argv) {
         cerr << "Problem creating log files. Check permissions of the log directory, " << acfg::logdir<<endl;
         exit(1);
     }
-    dbgline;
     
     _TestCacheDir();
 
@@ -98,14 +98,18 @@ int main(int argc, char **argv) {
 	if (acfg::foreground)
 		return conserver::Run();
 
-	daemon(0, 0);
+	if(daemon(0, 0))
+  {
+     cerr << "Failed to change to daemon mode" << endl;
+     exit(43);
+  }
 
 	if (!acfg::pidfile.empty()) {
 		mkbasedir(acfg::pidfile);
 		FILE *PID_FILE = fopen(acfg::pidfile.c_str(), "w");
 		if (PID_FILE != NULL) {
 			fprintf(PID_FILE, "%d", getpid());
-			forceFclose(PID_FILE);
+			checkForceFclose(PID_FILE);
 		}
 	}
 	return conserver::Run();
@@ -116,16 +120,15 @@ static void usage() {
 	cout <<"Usage: apt-cacher -h -c configdir <var=value ...>\n\n"
 		"Options:\n"
 		"-h: this help message\n"
-		"-c configuration directory\n"
-		"-e: run expiration on startup\n\n"
+		"-c: configuration directory\n"
+		"-e: on startup, run expiration once\n\n"
 		"Most interesting variables:\n"
-		"Daemon: 1 Daemonize program\n"
-		"PidFile: /path/to/pidfile File to store daemon's PID\n"
-		"FifoPath: /path/to/fifofile FIFO file, for control and local communication\n"
+		"ForeGround: Don't detach (default: 0)\n"
+		"Port: TCP port number (default: 3142)\n"
 		"CacheDir: /directory/for/storage\n"
 		"LogDir: /directory/for/logfiles\n"
 		"\n"
-		"See manpage for all directives.\n\n";
+		"See configuration examples for all directives.\n\n";
 	exit(0);
 }
 
@@ -152,7 +155,7 @@ static void _TestCacheDir() {
 
 void log_handler(int)
 {
-	aclog::reopen();
+	aclog::close(true);
 }
 
 void term_handler(int signum)
@@ -162,7 +165,7 @@ void term_handler(int signum)
 	case (SIGTERM):
 	case (SIGINT):
 	case (SIGQUIT):
-		aclog::close();
+		aclog::close(false);
 		// enough of the other crap, too unreliable behaviour WRT C++ cleanup and workarounds in code
 		// would be lame. Just let the OS help with the suizide.
 		signal(SIGINT, SIG_DFL);
