@@ -31,7 +31,7 @@ con::con(int fdId, const char *c) :
 	if(c) // if NULL, pick up later when sent by the wrapper
 		m_sClientHost=c;
 	
-    ldbg("Creating con " << fdId << " for " << c);
+    LOGSTART2("con::con", "fd: " << fdId << ", clienthost: " << c);
 
     
 #ifdef KILLABLE
@@ -60,14 +60,11 @@ void con::SignalStop() {
 //void DumpItems();
 
 con::~con() {
-	ldbg("Destroying connection...");
+	LOGSTART("con::~con (Destroying connection...)");
+	flushShutdownClose(m_confd);
 
-	if(m_confd>=0) 
-	{
-		shutdown(m_confd, SHUT_RDWR);
-		forceclose(m_confd);
-		m_confd=-1;
-	}
+	// our user's connection is released but the downloader task created here may still be serving others
+	// tell it to stop when it gets the chance and delete it then
 
 	MYSTD::list<job*>::iterator jit;
 	for (jit=m_jobs2send.begin(); jit!=m_jobs2send.end(); jit++)
@@ -185,6 +182,8 @@ public:
 };
 
 void con::WorkLoop() {
+
+	LOGSTART("con::WorkLoop");
     
 	signal(SIGPIPE, SIG_IGN);
 	
@@ -321,7 +320,7 @@ void con::WorkLoop() {
 			{
 				case(job::R_DISCON):
 				{
-					ldbg("Disconnect advise received, stoping connection");
+					ldbg("Disconnect advise received, stopping connection");
 					return;
 				}
 				case(job::R_DONE):
