@@ -14,12 +14,10 @@
 #include "job.h"
 #include "dljob.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
+#include "fileio.h"
 #include <errno.h>
 #include <unistd.h>
 #include <dirent.h>
-#include <glob.h>
 
 #include <map>
 #include <string>
@@ -67,7 +65,7 @@ bool expiration::ProcessRegular(const string & sPath, const struct stat &stinfo)
 		char buf[50];
 		int n=snprintf(buf, sizeof(buf), "Scanning, found %u files...<BR>\n",
 				m_nProgTold+1);
-		maintenance::SendMsg(buf, n);
+		maintenance::SendChunk(buf, n);
 	}
 	 
 	if(0==sPath.compare(m_nDropPrefLen, 1, "_") && !m_bScanInternals)
@@ -83,7 +81,7 @@ bool expiration::ProcessRegular(const string & sPath, const struct stat &stinfo)
         return true;
     }
 
-	if (rechecks::FILE_INDEX == m_rex.getFiletype(sPath.c_str()))
+	if (rechecks::FILE_INDEX ==	rechecks::GetFiletype(sPath))
     {
         //cerr << "ifile: " <<sPath <<endl;
 		m_volatileFiles.insert(sPath);
@@ -116,7 +114,7 @@ void expiration::_LoadTrashMapFromFile(bool bForceInsert)
 		tStrVec elems;
 		if(Tokenize(sLine, "\t", elems)==3)
 		{
-			time_t timestamp=atoll(elems[0].c_str());
+			time_t timestamp=(time_t) atoll(elems[0].c_str());
 			if(timestamp>m_nTimeNow)
 				continue; // where is the DeLorean?
 			
@@ -175,7 +173,7 @@ void expiration::_LoadTrashMapFromFile(bool bForceInsert)
 				"to be deleted in about %d-%d day(s)<br>\n", 
 				(unsigned long) m_trashCandidates.size(),
 				nMin, nMax==nMin?nMax+1:nMax); // cheat a bit for the sake of code simplicity
-		SendMsg(buf);
+		SendChunk(buf);
 	}
 #endif
 
@@ -213,7 +211,7 @@ bool expiration::_DownloadOne(dlcon &dl, const MYSTD::string & sFilePath, string
 		goto rep_update_prob;
 	}
 	
-	SendMsg(string("Checking/Updating ")+sKeyPath+"...\n");
+	SendChunk(string("Checking/Updating ")+sKeyPath+"...\n");
 	pBackends = acfg::GetBackendVec(&url.sHost);
 	if (pBackends)
 		url.sPath.erase(0, 1); // get only the path string residual
@@ -244,11 +242,11 @@ bool expiration::_DownloadOne(dlcon &dl, const MYSTD::string & sFilePath, string
 			goto rep_update_prob;
 	}
 
-	SendMsg(string("<i>(")+ltos(fi->GetTransferCount()/1024)+("KiB)</i><br>\n"));
+	SendChunk(string("<i>(")+ltos(fi->GetTransferCount()/1024)+("KiB)</i><br>\n"));
 	
 	if (fi)
 	{
-		fileitem::DelUser(sKeyPath);
+		fi->Unreg();
 		fi.reset();
 	}
 	
@@ -264,14 +262,14 @@ bool expiration::_DownloadOne(dlcon &dl, const MYSTD::string & sFilePath, string
 			if (pErHead)
 				sErr+=string("Reason: ")+pErHead->frontLine+"<br>\n";
 		}
-		fileitem::DelUser(sKeyPath);
+		fi->Unreg();
 		fi.reset();
 	}
-	SendMsg("<br>\n");
+	SendChunk("<br>\n");
 	
 	if(_CanBeIgnored(sKeyPath))
 	{
-		SendMsg("<font color=\"orange\">Ignoring download failure as advised.</font><br>\n");
+		SendChunk("<font color=\"orange\">Ignoring download failure as advised.</font><br>\n");
 		return true;
 	}
 	return false;
@@ -315,8 +313,8 @@ protected:
 			if (!ph->h[header::CONTENT_LENGTH])
 				goto repErrLocal;
 
-			// .bz2 larger than 30mb? unlikely
-			if (atoll(ph->h[header::CONTENT_LENGTH]) > 30000000)
+			// .bz2 index and larger than 30mb? unlikely
+			if (atoofft(ph->h[header::CONTENT_LENGTH]) > 30000000)
 				goto repErrLocal;
 			
 			// some mirrors don't use -9, and some might use the mt version
@@ -383,11 +381,11 @@ void expiration::_InjectBz2ed(const MYSTD::string & sTargetBasePath,
 	string junk;
 	
 	dlcon freshDler(true); // get a new connection, work around timeouts
-	SendMsg("Attempting to inject bz2ed version...");
+	SendChunk("Attempting to inject bz2ed version...");
 	if(_UpdateOne(freshDler, sTargetBasePath+".bz2", junk, &hints))
-		SendMsg("succeeded<br>\n");
+		SendChunk("succeeded<br>\n");
 	else
-		SendMsg("skipped<br>\n");
+		SendChunk("skipped<br>\n");
 }
 
 
@@ -403,7 +401,7 @@ bool expiration::_UpdateOne(dlcon &dl, const MYSTD::string & sFilePath, string &
 	string sKeyPath=sFilePath.substr(acfg::cachedir.size()+1, stmiss);
 	
 	if(!pSpecialHints) // running wrapped, STFU
-		SendMsg(string("Checking/Updating ")+sKeyPath+"...\n");
+		SendChunk(string("Checking/Updating ")+sKeyPath+"...\n");
 	
 	fi=fileitem::GetFileItem(sKeyPath);
 	if (fi)
@@ -485,7 +483,7 @@ bool expiration::_UpdateOne(dlcon &dl, const MYSTD::string & sFilePath, string &
 					 * */
 					if (m_bVerbose || url.sHost.find(".") != stmiss)
 					{
-						SendMsg(string("<font color=\"orange\">Code 520824! "
+						SendChunk(string("<font color=\"orange\">Code 520824! "
 							"Read the manual about known bugs! Attempting to use ")
 								+ url.sHost + " as hostname</font>");
 					}
@@ -506,11 +504,11 @@ bool expiration::_UpdateOne(dlcon &dl, const MYSTD::string & sFilePath, string &
 	}
 
 	//if(!pSpecialHints)
-		SendMsg(string("<i>(")+ltos(fi->GetTransferCount()/1024)+("KiB)</i><br>\n"));
+		SendChunk(string("<i>(")+ltos(fi->GetTransferCount()/1024)+("KiB)</i><br>\n"));
 	
 	if (fi)
 	{
-		fileitem::DelUser(sKeyPath);
+		fi->Unreg();
 		fi.reset();
 	}
 	
@@ -527,14 +525,14 @@ bool expiration::_UpdateOne(dlcon &dl, const MYSTD::string & sFilePath, string &
 			if (pErHead)
 				sErr+=string("Reason: ")+pErHead->frontLine+"<br>\n";
 		}
-		fileitem::DelUser(sKeyPath);
+		fi->Unreg();
 		fi.reset();
 	}
-	SendMsg("<br>\n");
+	SendChunk("<br>\n");
 	
 	if(_CanBeIgnored(sKeyPath))
 	{
-		SendMsg("<font color=\"orange\">Ignoring download failure as advised.</font><br>\n");
+		SendChunk("<font color=\"orange\">Ignoring download failure as advised.</font><br>\n");
 		return true;
 	}
 	return false;
@@ -633,7 +631,7 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 			if(startsWithSz(sLine, "SHA1-Current: "))
 			{
 				//SendMsg(sLine + " ist current");
-				nCurrentSize=atoll(sLine.c_str()+54);
+				nCurrentSize=atoofft(sLine.c_str()+54);
 				// detect obvious errors
 				if(sLine[54] != ' ' || ! nCurrentSize)
 				{
@@ -699,7 +697,7 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 					&& Meta::CsEqual( (CUCHAR*) sCurrentCs.c_str(), srcHexCs, 20))
 			{
 				if(m_bVerbose)
-					SendMsg(sGuessSrc+": content match, using this version<br>\n"); // Ignore all other files!
+					SendChunk(sGuessSrc+": content match, using this version<br>\n"); // Ignore all other files!
 				::unlink(sTmpFile.c_str());
 				
 				// drop any other (older) version from the list, use only the new one
@@ -726,7 +724,7 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 				//SendMsg(stateList[hit] + " <- testing<br>");				
 				if(Meta::CsEqual((CUCHAR*) stateList[hit].c_str(), 
 						srcHexCs, 20)
-					&& srcSize==atoll(stateList[hit+1].c_str()) )
+					&& srcSize==atoofft(stateList[hit+1].c_str()) )
 				{
 					break; // GOTCHA! The index state to start patching
 				}
@@ -760,7 +758,7 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 					if(stateList[pIdx] == patchSums[i+2])
 					{
 						if(! Meta::CsEqual((CUCHAR*) patchSums[i].c_str(), tmpHexCs, 20)
-								|| atoll(patchSums[i+1].c_str()) != tmpSize)
+								|| atoofft(patchSums[i+1].c_str()) != tmpSize)
 						{
 							aclog::err(sPatchFn+": bad checksum or filesize");
 							goto clean_stuff_and_continue;
@@ -794,7 +792,7 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 						+ CsBinToString(tmpHexCs, 20)) != validCsums.end())
 				{
 					// GOOD! Looks very valid
-					SendMsg(string("Patching... OK, updating ")+sBaseFn+"<br>");
+					SendChunk(string("Patching... OK, updating ")+sBaseFn+"<br>");
 					::unlink(sBaseFn.c_str());
 					::unlink((sBaseFn+".head").c_str());
 					
@@ -812,14 +810,14 @@ void expiration::_UpdateWithDiffs(dlcon &dl, tStrSet & listGuessedLocationsToTry
 				}
 				else
 				{
-					SendMsg(string("Patching... finished with errors, ")+sBaseFn+" will be redownloaded<br>\n");
+					SendChunk(string("Patching... finished with errors, ")+sBaseFn+" will be redownloaded<br>\n");
 				}
 			}
 			else
 			{
-				SendMsg("Patching... failed, is ed installed?<br>");
+				SendChunk("Patching... failed, is ed installed?<br>");
 				if(acfg::debug>1)
-					SendMsg(sCmd);
+					SendChunk(sCmd);
 			}
 			clean_stuff_and_continue:
 			for(tStrVecIter it = cleanSet.begin(); it!=cleanSet.end(); it++)
@@ -929,9 +927,9 @@ void expiration::_UpdateVolatileFiles()
 		if (!_UpdateOne(dl, *it, sErr))
 		{
 			m_nErrorCount++;
-			SendMsg("Error while redownloading this file!<br>\n ");
+			SendChunk("Error while redownloading this file!<br>\n ");
 			if (!sErr.empty())
-				SendMsg(string("Reason: ")+sErr+"<br>\n");
+				SendChunk(string("Reason: ")+sErr+"<br>\n");
 		}
 	}
 	
@@ -955,6 +953,7 @@ void expiration::_UpdateVolatileFiles()
 
 inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatcher)
 {
+	LOGSTART("expiration::_ParseVolatileFilesAndHandleEntries");
 	for(tStrSet::const_iterator it=m_volatileFiles.begin(); it!=m_volatileFiles.end(); it++)
 	{
 		if(it->empty() || it->at(0)!=cPathSepUnix)
@@ -971,7 +970,7 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 						&& pDupeCatcher->find(sSrcSig) != pDupeCatcher->end())
 				{
 					//SendMsg("found dupe in the catchup ;-)<br>");
-					SendMsg(string("Ignoring ")
+					SendChunk(string("Ignoring ")
 							+it->substr(m_nDropPrefLen)
 							+" (equivalent file seen)<br>\n");
 					continue;
@@ -979,11 +978,11 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 			}
 		}
 		
-		SendMsg(string("Parsing metadata in ")+it->substr(m_nDropPrefLen)+"<br>\n");
+		SendChunk(string("Parsing metadata in ")+it->substr(m_nDropPrefLen)+"<br>\n");
 		filereader reader;
 		if(!reader.OpenFile(*it))
 		{
-			SendMsg("<font color=red>ERROR: unable to open or read this file</font><br>\n");
+			SendChunk("<font color=red>ERROR: unable to open or read this file</font><br>\n");
 			continue;
 		}
 		string sLine, key, val;
@@ -1006,9 +1005,10 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 		tRemoteFileInfo info;
 		info.SetInvalid();
 		
-		if (sFile=="Packages")
+		if (sFile=="Packages") // Debian's Packages file
 		{
-			string csNeeded("MD5sum"), fnNeeded("Filename"), szNeeded("Size");
+			LOG("filetype: Packages file")
+			static string sMD5sum("MD5sum"), sFilename("Filename"), sSize("Size");
 			
 			for (bool bNoEof=true; bNoEof;)
 			{
@@ -1029,14 +1029,14 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 				else if (_ParseLine(sLine, key, val))
 				{
 					// not looking for data we already have
-					if(/*CSTYPE_INVALID == info.fpr.csType &&*/ 32==val.length() && key==csNeeded)
+					if(32==val.length() && key==sMD5sum)
 					{
 						info.fpr.csType=CSTYPE_MD5;
 						info.fpr.ReadCsFromString(val);
 					}
-					else if(/*0==info.fpr.size && */key==szNeeded)
-						info.fpr.size=atol(val.c_str());
-					else if(/*info.sFileName.empty() && */key==fnNeeded)
+					else if(key==sSize)
+						info.fpr.size=atoofft(val.c_str());
+					else if(key==sFilename)
 					{
 						info.sDirectory=sDebBaseDir;
 						tStrPos pos=val.rfind(sPathSepUnix);
@@ -1051,17 +1051,70 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 				}
 			}
 		}
-		else // sources-style formats
+		else if(sFile=="setup")
 		{
+			LOG("assuming Cygwin package setup listing";)
+			static const string keys[]={"install: ", "source: "};
+			tStrVec vFileSizeSum;
+
+			for (bool bNoEof=true; bNoEof;)
+			{
+				if(CheckAbortCondition())
+					return;
+
+				bNoEof=reader.GetOneLine(sLine);
+				trimBack(sLine);
+				for(UINT i=0;i<_countof(keys);i++)
+				{
+					if(!startsWith(sLine, keys[i]))
+						continue;
+					//LOG("interesting line: " << sLine);
+					if (3==Tokenize(sLine, "\t ", vFileSizeSum, false, keys[i].length())
+							&& vFileSizeSum[2].length()>30)
+					{
+						//LOG("found tree items, checking");
+						info.fpr.csType=CSTYPE_MD5;
+						info.fpr.bUnpack=false;
+						if( 0 < (info.fpr.size=atoofft(vFileSizeSum[1].c_str()))
+								&& info.fpr.ReadCsFromString(vFileSizeSum[2]))
+						{
+							//LOG("looks ok");
+
+							tStrPos pos = vFileSizeSum[0].rfind(sPathSepUnix);
+							if (pos == stmiss)
+							{
+								info.sFileName = vFileSizeSum[0];
+								info.sDirectory = sDirname;
+							}
+							else
+							{
+								info.sFileName
+										= vFileSizeSum[0].substr(pos + 1);
+								info.sDirectory = sDirname
+										+vFileSizeSum[0].substr(0, pos + 1);
+							}
+
+							_HandlePkgEntry(info);
+							info.SetInvalid();
+						}
+					}
+				}
+			}
+		}
+		else // Debian sources-style formats
+		{
+			LOG("filetype: Sources file format or similar")
 			/* pickup all common information, then parse the remaining lines and
 			 * assign the tokens to fields in each call of the callback function
 			 */
 			tStrVec vSumSizeName;
 			string sStartMark;
 			bool bUse(false);
+			enum tTypeHint { _index, _sources, _release } typehint;
 			
 			if (sFile=="Index")
 			{
+				typehint = _index;
 				info.fpr.csType = CSTYPE_SHA1;
 				info.fpr.bUnpack = true;
 				info.sDirectory=sDirname; // same for all
@@ -1069,19 +1122,20 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 			}
 			else if (sFile=="Sources")
 			{
+				typehint = _sources;
 				info.fpr.csType = CSTYPE_MD5;
 				info.fpr.bUnpack = false;
 				sStartMark="Files:";
 			}
 			else if (sFile=="Release")
 			{
+				typehint = _release;
 				info.fpr.csType = CSTYPE_MD5;
 				info.fpr.bUnpack = false;
 				sStartMark="MD5Sum:";
 			}
 			else
 				continue;
-			const char typehint=sFile[0];
 			
 			for (bool bNoEof=true; bNoEof;)
 			{
@@ -1110,20 +1164,19 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 						)
 						
 				{
-				
-					info.fpr.size = atol(vSumSizeName[1].c_str());
+					info.fpr.size = atoofft(vSumSizeName[1].c_str());
 					if(info.fpr.size && info.fpr.ReadCsFromString(vSumSizeName[0]))
 					{
 
-						if (typehint=='S')//ources
+						if (_sources == typehint)
 							info.sFileName=vSumSizeName[2];
-						else if (typehint=='I')//ndex
+						else if (_index == typehint)
 						{
 							// We cheat! Files there are compressed and thus the checksum is wrong, deal with that later
 							info.sFileName=vSumSizeName[2]+".gz";
 							//info.sDirectory=sDirname;
 						}
-						else if (typehint=='R')//elease
+						else if (_release ==typehint)
 						{
 							// usually has subfolders
 							pos=vSumSizeName[2].rfind(sPathSepUnix);
@@ -1158,7 +1211,7 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 		}
 		else
 		{
-			SendMsg("<font color=red>An error occured while reading this file, some contents may have been ignored.</font><br>\n");
+			SendChunk("<font color=red>An error occured while reading this file, some contents may have been ignored.</font><br>\n");
 			m_nErrorCount++;
 			continue;
 		}
@@ -1168,7 +1221,11 @@ inline void expiration::_ParseVolatileFilesAndHandleEntries(tStrSet *pDupeCatche
 
 void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 {
-	//aclog::err(string("wtf:")+entry.sDirectory+entry.sFileName);
+	LOGSTART2("expiration::_HandlePkgEntry:",
+			"dir:" << entry.sDirectory << endl<<
+			"name: " << entry.sFileName << endl<<
+			"size: " << entry.fpr.size <<endl<<
+			"csum: " << entry.fpr.GetCsAsString());
 	
 	// singleton -> keep some things static == optimization
 	static pair<tS2DAT::iterator, tS2DAT::iterator> fromTo;
@@ -1207,7 +1264,7 @@ void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 			{
 				if (h.h[header::CONTENT_LENGTH])
 				{
-					off_t len=atoll(h.h[header::CONTENT_LENGTH]);
+					off_t len=atoofft(h.h[header::CONTENT_LENGTH]);
 					struct stat stinfo;
 					off_t lenInfo=0;
 					
@@ -1222,13 +1279,13 @@ void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 						lenInfo = stinfo.st_size;
 					else
 					{
-						SendMsg(sShortPath+ ": error reading attributes, ignoring");
+						SendChunk(sShortPath+ ": error reading attributes, ignoring");
 						goto keep_in_trash;
 					}
 					
 					if(len<lenInfo)
 					{
-						SendMsg(string("<font color=red>WARNING, header file of ")
+						SendChunk(string("<font color=red>WARNING, header file of ")
 								+ sShortPath
 								+ " reported too small file size, invalidating "
 								+it->first+"</font><br>\n");
@@ -1237,13 +1294,13 @@ void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 				}
 				else
 				{
-					SendMsg(string("<font color=red>WARNING, header file of ")
+					SendChunk(string("<font color=red>WARNING, header file of ")
 							+ sShortPath + " does not contain content length");
 					goto keep_in_trash;
 				}
 			}
 			else
-				SendMsg(string("<font color=\"orange\">WARNING, header file missing for ")
+				SendChunk(string("<font color=\"orange\">WARNING, header file missing for ")
 						+sFullPath+"</font><br>\n");
 		}
 		
@@ -1271,7 +1328,7 @@ void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 			{
 				if ( ! (fprFile == entry.fpr))
 				{
-					SendMsg(string("<font color=red>BAD: ")+sFullPath
+					SendChunk(string("<font color=red>BAD: ")+sFullPath
 					+"</font><br>\n");
 					goto keep_in_trash;
 				}
@@ -1280,7 +1337,7 @@ void expiration::_HandlePkgEntry(const tRemoteFileInfo &entry)
 		
 		// ok, package matched, contents ok if checked, drop it from the removal list
 		if (m_bVerbose)
-			SendMsg(string("<font color=green>OK: ")+it->second.sDirname
+			SendChunk(string("<font color=green>OK: ")+it->second.sDirname
 					+it->first+"</font><br>\n");
 
 		itmp=it;
@@ -1307,14 +1364,14 @@ inline void expiration::_RemoveAndStoreStatus(bool bPurgeNow)
         f = fopen(sDbFile.c_str(), "w");
         if(!f)
         {
-            SendMsg("Unable to open _expending.dat for writing, trying to recreate... ");
+            SendChunk("Unable to open _expending.dat for writing, trying to recreate... ");
             ::unlink(sDbFile.c_str());
             f=::fopen(sDbFile.c_str(), "w");
             if(f)
-                SendMsg("OK<br>\n");
+                SendChunk("OK<br>\n");
             else
             {
-                SendMsg("<font color=red>FAILED. ABORTING. Check filesystem and file permissions.");
+                SendChunk("<font color=red>FAILED. ABORTING. Check filesystem and file permissions.");
                 return;
             }
         }
@@ -1324,8 +1381,7 @@ inline void expiration::_RemoveAndStoreStatus(bool bPurgeNow)
 	for(tS2DAT::iterator it=m_trashCandSet.begin(); 
             it!=m_trashCandSet.end(); it++)
 	{
-        if(m_rex.IsInWhitelist(it->first.c_str()))
-        	continue;
+        if(rechecks::MatchWhitelist(it->first)) continue;
 
 		//cout << "Unreferenced: " << it->second.sDirname << it->first <<endl;
 
@@ -1337,7 +1393,7 @@ inline void expiration::_RemoveAndStoreStatus(bool bPurgeNow)
 
 		if(bPurgeNow || (it->second.nLostAt < (m_nTimeNow-acfg::extreshhold*86400)))
 		{
-			SendMsg(string("Tagging ")+it->second.sDirname+it->first+"<br>\n");
+			SendChunk(string("Tagging ")+it->second.sDirname+it->first+"<br>\n");
 
 #ifdef ENABLED
 			::unlink(sWhat.c_str());
@@ -1359,9 +1415,7 @@ inline void expiration::_RemoveAndStoreStatus(bool bPurgeNow)
 	for(set<string>::iterator it=m_trashCandHeadSet.begin();
             it!=m_trashCandHeadSet.end(); it++)
 	{
-        // keep Release etc.
-		if(m_rex.IsInWhitelist(it->c_str()))
-            continue;
+        if(rechecks::MatchWhitelist(*it)) continue;
 		
         cout << "Removing orphaned head file: " << *it << endl;
 #ifdef ENABLED
@@ -1376,7 +1430,7 @@ inline void expiration::_RemoveAndStoreStatus(bool bPurgeNow)
     {
         char buf[100];
         snprintf(buf, _countof(buf), "<br>\n%d package file(s) marked for removal in few days.<br>\n<br>\n", n);
-        SendMsg(buf);
+        SendChunk(buf);
     }
 }
 
@@ -1397,13 +1451,13 @@ void expiration::Action(const string & cmd)
 		for (tS2DAT::iterator it=m_trashCandSet.begin(); it
 				!=m_trashCandSet.end(); it++)
 		{
-			SendMsg(it->second.sDirname+it->first+"<br>\n");
-			SendMsg(it->second.sDirname+it->first+".head<br>\n");
+			SendChunk(it->second.sDirname+it->first+"<br>\n");
+			SendChunk(it->second.sDirname+it->first+".head<br>\n");
 		}
 		return;
 	}
 	
-	SendMsg("Locating potentially expired files in the cache...<br>\n");
+	SendChunk("Locating potentially expired files in the cache...<br>\n");
 
 	m_bErrAbort=(cmd.find("abortOnErrors=aOe")!=stmiss);
 	m_bByPath=(cmd.find("byPath")!=stmiss);
@@ -1417,7 +1471,7 @@ void expiration::Action(const string & cmd)
 		return;
 	//cout << "found package files: " << m_trashCandidates.size()<<endl;
 
-	SendMsg("Redownloading index files...<br>\n");
+	SendChunk("Redownloading index files...<br>\n");
 
 	_UpdateVolatileFiles();
 	
@@ -1427,12 +1481,12 @@ void expiration::Action(const string & cmd)
 
 	if (m_bErrAbort && m_nErrorCount>0)
 	{
-		SendMsg("<font color=\"red\">Found errors during processing, aborting as requested.</font>"
+		SendChunk("<font color=\"red\">Found errors during processing, aborting as requested.</font>"
 			"<!-- TELL:THE:ADMIN -->");
 		return;
 	}
 
-	SendMsg("Identifying fresh files...<br>\n");
+	SendChunk("Identifying fresh files...<br>\n");
 	tStrSet catchup;
 
 	_ParseVolatileFilesAndHandleEntries(&catchup);
@@ -1445,36 +1499,28 @@ void expiration::Action(const string & cmd)
 	
 	_RemoveAndStoreStatus(cmd.find("purgeNow")!=stmiss);
 	_PurgeMaintLogs();
-	SendMsg("Done.");
+	SendChunk("Done.");
 
 }
 
 
 void expiration::_PurgeMaintLogs()
 {
-	glob_t globbuf;
-	memset(&globbuf, 0, sizeof(glob_t));
-	string pattern=acfg::logdir+SZPATHSEP"maint_*.log";
-	glob(pattern.c_str(), GLOB_DOOFFS | GLOB_NOSORT, NULL, &globbuf);
-	if (globbuf.gl_pathc>2)
+	tStrVec logs = ExpandFilePattern(acfg::logdir + SZPATHSEP"maint_*.log");
+	if (logs.size() > 2)
+		SendChunk(
+				"Found required cleanup tasks: purging maintanence logs...<br>\n");
+	for (tStrVecIterConst it = logs.begin(); it != logs.end(); it++)
 	{
-		SendMsg("Found required cleanup tasks: purging maintanence logs...<br>\n");
-	}
-	for (unsigned int i=0; i<globbuf.gl_pathc; i++)
-	{
-		//cerr << "Checking "<<globbuf.gl_pathv[i];
-		// skip our log
-		time_t id=atol(globbuf.gl_pathv[i]+acfg::logdir.size()+7);
+		time_t id = atoofft(it->c_str() + acfg::logdir.size() + 7);
 		//cerr << "id ist: "<< id<<endl;
-		if (id==GetTaskId())
+		if (id == GetTaskId())
 			continue;
 		//cerr << "Remove: "<<globbuf.gl_pathv[i]<<endl;
 #ifdef ENABLED
-		::unlink(globbuf.gl_pathv[i]);
+		::unlink(it->c_str());
 #endif
 	}
-	globfree(&globbuf);
-
 }
 
 
