@@ -2,9 +2,7 @@
 #include "filereader.h"
 
 #include <unistd.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#include "fileio.h"
 #include <fcntl.h>
 #include <sys/mman.h>
 #include <errno.h>
@@ -164,7 +162,6 @@ void filereader::Close()
 	{
 		fsync(m_fd);
 		forceclose(m_fd);
-		m_fd=-1;
 	}
 	
 #ifdef HAVE_LIBBZ2
