@@ -12,10 +12,10 @@
 #include <time.h>
 #include <iostream>
 #include <string.h>
-
-#include <errno.h>
 #include <unistd.h>
 
+#include "fileio.h"
+
 using namespace MYSTD;
 
 struct {
@@ -248,7 +248,7 @@ int header::StoreToFile(const string &sPath)
 {
 	int nByteCount(0);
 	
-	int fd=open(sPath.c_str(), O_WRONLY|O_CREAT|O_TRUNC, CREATPERMS);
+	int fd=open(sPath.c_str(), O_WRONLY|O_CREAT|O_TRUNC, acfg::fileperms);
 	if(fd<0)
 		return -errno;
 	
