@@ -18,7 +18,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
-//#include <iostream>
 
 #include <unistd.h>
 #include <signal.h>
@@ -27,10 +26,6 @@ using namespace MYSTD;
 
 #define MAINT_HTML_DECO "maint.html" 
 
-#ifndef MSG_MORE
-#define MSG_MORE 0
-#endif
-
 maintenance::maintenance(int fd) :
 	m_reportFD(fd),
 	m_szDecoFile(NULL)
@@ -44,12 +39,12 @@ maintenance::~maintenance()
 /// @brief Sends a HTTP chunk with string contents
 /// To terminate the transfer, add an empty string with force flag
 
-void maintenance::SendMsg(const string & x) 
+void maintenance::SendChunk(const string & x) 
 {
-    SendMsg(x.data(), x.length());
+    SendChunk(x.data(), x.length());
 }
 
-bool maintenance::_SendHelper(const char *data, size_t len, int flags)
+bool maintenance::SendRawData(const char *data, size_t len, int flags)
 {
 	while(len>0)
 	{
@@ -68,38 +63,38 @@ bool maintenance::_SendHelper(const char *data, size_t len, int flags)
 	return true;
 }
 
-void maintenance::SendMsg(const char *data, size_t len)
+void maintenance::SendChunk(const char *data, size_t len)
 {
 	if(!data || !len || m_reportFD<0)
 		return;
 	
 	char buf[23];
 	int l=sprintf(buf, "%x\r\n", (UINT) len);
-	_SendHelper(buf, l, MSG_MORE|MSG_NOSIGNAL);
-	_SendHelper(data, len, MSG_MORE|MSG_NOSIGNAL);
-	_SendHelper("\r\n", 2, MSG_NOSIGNAL);
+	SendRawData(buf, l, MSG_MORE|MSG_NOSIGNAL);
+	SendRawData(data, len, MSG_MORE|MSG_NOSIGNAL);
+	SendRawData("\r\n", 2, MSG_NOSIGNAL);
 }
 
 void maintenance::EndTransfer() 
 {
 	const char msg[] = "0\r\n\r\n"; 
-	_SendHelper(msg, sizeof(msg)-1, MSG_NOSIGNAL);
+	SendRawData(msg, sizeof(msg)-1, MSG_NOSIGNAL);
 }
 
-
-void maintenance::SendDecoration(bool bBegin, const char *httpcode, const char *szDecoFile)
+void maintenance::SendChunkedPageHeader(const char *httpcode, const char *mimetype)
 {
-	if (bBegin)
-	{
-		const char hs[]="HTTP/1.1 ";
-		const char head[] = " OK\r\nConnection: close\r\n"
-			"Transfer-Encoding: chunked\r\nContent-Type: text/html\r\n"
-			"\r\n";
-		_SendHelper(hs, sizeof(hs)-1, MSG_MORE);
-		_SendHelper(httpcode, strlen(httpcode), MSG_MORE);
-		_SendHelper(head, sizeof(head)-1, MSG_MORE);
-	}
-	
+	MYSTD::string buf("HTTP/1.1 ");
+	buf+=(httpcode ? httpcode : "200");
+	buf+=" OK\r\nConnection: close\r\n"
+		"Transfer-Encoding: chunked\r\nContent-Type: ";
+	buf+=(mimetype?mimetype:"text/html");
+	buf+="\r\n\r\n";
+	SendRawData(buf.data(), buf.length(), MSG_MORE);
+}
+/*
+void maintenance::SendDecoration(bool bBegin, const char *szDecoFile)
+{
+
 	acbuf m_deco;
 	char *mark(NULL);
 	
@@ -123,7 +118,7 @@ void maintenance::SendDecoration(bool bBegin, const char *httpcode, const char *
 	if(!bBegin)
 		EndTransfer();
 }
-
+*/
 class authbounce : public maintenance
 {
 public:
@@ -144,7 +139,7 @@ public:
         "Connection: Close\r\n"
         "Content-Type: text/html\r\nContent-Length:81\r\n\r\n"
         "Not Authorized. Please contact Apt-Cacher NG administrator for further questions.";
-		_SendHelper(authmsg, sizeof(authmsg)-1, 0);
+		SendRawData(authmsg, sizeof(authmsg)-1, 0);
 	}
 	
 };
@@ -173,12 +168,14 @@ void DispatchAndRunMaintTask(const MYSTD::string &cmd, int conFD, const char * s
 			else if(cmd.find("doImport=")!=stmiss)
 				pWorker=new pkgimport(conFD);
 			else if(cmd.find("doCount=")!=stmiss)
-				pWorker = new reportgen(conFD, true);
+				pWorker = new tStaticFileSend(conFD, "report.html", "text/html", "200");
 		}
 		else if (cmd==acfg::reportpage)
-			pWorker = new reportgen(conFD, false);
+			pWorker = new tStaticFileSend(conFD, "report.html", "text/html", "200");
+		else if (cmd == "/style.css")
+			pWorker = new tStaticFileSend(conFD, "style.css", "text/css", "200");
 		else
-			pWorker = new showinfo(conFD);
+			pWorker = new tStaticFileSend(conFD, "userinfo.html", "text/html", "404");
 
 		if(pWorker)
 			pWorker->Run(cmd);
