@@ -3,11 +3,20 @@
 #include "debug.h"
 
 #include "meta.h"
-#include <sys/types.h>
-#include <sys/stat.h>
+#include "fileio.h"
 #include <unistd.h>
+#include <cstring>
 #include <cstdio>
 #include <iostream>
+#include <algorithm>
+
+#ifdef HAVE_WORDEXP
+#include <wordexp.h>
+#elif defined(HAVE_GLOB)
+#include <glob.h>
+#endif
+
+
 using namespace MYSTD;
 
 string sPathSep(SZPATHSEP);
@@ -30,14 +39,6 @@ void set_nb(int fd) {
     flags = fcntl(fd, F_SETFL, flags);
 }
 
-void mkbasedir(const MYSTD::string & path)
-{
-    for(UINT pos=0; pos<path.size(); pos=path.find("/", pos+1))
-    {
-        if(pos>0)
-            mkdir(path.substr(0,pos).c_str(), 00755);
-    }
-}
 /*
 inline tStrPos findHostStart(const MYSTD::string & sUri)
 {
@@ -108,13 +109,16 @@ void find_base_name(const char *in, const char * &pos, UINT &len)
 }
 */
 
-tStrVec::size_type Tokenize(const string & in, const char *sep, tStrVec & out, bool bAppend)
+/*!
+ * \brief Simple split function, outputs resulting tokens into a string vector, with or without purging the previous contents
+ */
+tStrVec::size_type Tokenize(const string & in, const char *sep, tStrVec & out, bool bAppend, MYSTD::string::size_type nStartOffset)
 {
 	if(!bAppend)
 		out.clear();
 	tStrVec::size_type nBefore(out.size());
 	
-	tStrPos pos=0, pos2=0, oob=in.length();
+	tStrPos pos=nStartOffset, pos2=nStartOffset, oob=in.length();
 	while (pos<oob)
 	{
 		pos=in.find_first_not_of(sep, pos);
@@ -300,3 +304,44 @@ const MYSTD::string GetDateString() {
     
 }
 */
+
+#if defined(HAVE_WORDEXP) || defined(HAVE_GLOB)
+
+tStrVec ExpandFilePattern(const string &pattern, bool bSorted)
+{
+	tStrVec srcs;
+#ifdef HAVE_WORDEXP
+	wordexp_t p;
+	memset(&p, 0, sizeof(p));
+    if(0==wordexp(pattern.c_str(), &p, 0))
+    {
+    	for(char **s=p.we_wordv; s<p.we_wordv+p.we_wordc;s++)
+    		srcs.push_back(*s);
+    	wordfree(&p);
+    }
+    if(bSorted) MYSTD::sort(srcs.begin(), srcs.end());
+#elif defined(HAVE_GLOB)
+	glob_t p;
+	memset(&p, 0, sizeof(p));
+	if(0==glob(pattern.c_str(), GLOB_DOOFFS | (bSorted ? 0 : GLOB_NOSORT),
+			NULL, &p))
+	{
+		for(char **s=p.gl_pathv; s<p.gl_pathv+p.gl_pathc;s++)
+			srcs.push_back(*s);
+		globfree(&p);
+	}
+#else
+#warning Needs a file name expansion function, wordexp or glob
+	srcs.push_back(pattern);
+#endif
+
+	return srcs;
+}
+#else // -> no wordexp, no glob
+tStrVec GetStringAsVector(const string &s)
+{
+	tStrVec ret;
+	ret.push_back(s);
+	return s;
+}
+#endif
