@@ -78,8 +78,7 @@ bool pkgimport::ProcessRegular(const string &sPath, const struct stat &stinfo)
 		return true;
 	
 	//string sRelName=fileNode->sPath.substr(acfg::cachedir.length()+1);
-	rechecks::eFileKind kind = m_rex.getFiletype(sPath.c_str());
-
+	rechecks::eFileKind kind = rechecks::GetFiletype(sPath);
 	if(m_bPickIfiles)
 	{
 		if(0==sPath.compare(m_nDropPrefLen, 1, "_"))
@@ -101,12 +100,12 @@ bool pkgimport::ProcessRegular(const string &sPath, const struct stat &stinfo)
 		tFingerprint *fpr=CsTypeGuessing(sPath);
 		if (fpr->ReadCsFromFile(sPath))
 		{
-			SendMsg(string("<font color=blue>Checked ")+sPath
+			SendChunk(string("<font color=blue>Checked ")+sPath
 					+" (fingerprint created)</font><br>\n");
 		}
 		else
 		{
-			SendMsg(string("<font color=red>Error checking ")+sPath
+			SendChunk(string("<font color=red>Error checking ")+sPath
 					+"</font><br>\n");
 			return true;
 		}
@@ -120,7 +119,7 @@ bool pkgimport::ProcessRegular(const string &sPath, const struct stat &stinfo)
 		}
 		else if(node.sPath!=sPath)
 		{
-			SendMsg(string("<font color=orange>Duplicate found, ")+sPath
+			SendChunk(string("<font color=orange>Duplicate found, ")+sPath
 								+" vs. "+node.sPath+", ignoring new entry.</font><br>\n");
 		}
 	}
@@ -174,10 +173,9 @@ bool FileCopy(const string &from, const string to)
 	return true;
 
 	error_copying: 
-	if (in>=0)
-		forceclose(in);
-	if (out>=0)
-		forceclose(out);
+
+	checkforceclose(in);
+	checkforceclose(out);
 	return false;
 }
 bool pkgimport::LinkOrCopy(const MYSTD::string &from, const MYSTD::string &to)
@@ -216,7 +214,7 @@ bool pkgimport::LinkOrCopy(const MYSTD::string &from, const MYSTD::string &to)
 		if (0==link(from.c_str(), to.c_str()))
 			return true;
 
-		SendMsg("(couldn't link, copying contents)");
+		SendChunk("(couldn't link, copying contents)");
 		if(!FileCopy(from,to))
 			return false;
 		
@@ -236,11 +234,11 @@ void pkgimport::Action(const string &cmd)
 // TODO: import path from cmd?
 	m_sSrcPath=acfg::cachedir+sPathSep+"_import";
 	
-	SendMsg(string("Importing from ")+m_sSrcPath+" directory, scanning...<br>\n");
+	SendChunk(string("Importing from ")+m_sSrcPath+" directory, scanning...<br>\n");
 	
 	_LoadKeyCache(SCACHEFILE);
 	if(!m_precachedList.empty())
-		SendMsg(string("Loaded ")+ltos(m_importMap.size())
+		SendChunk(string("Loaded ")+ltos(m_importMap.size())
 				+(m_precachedList.size()==1 ? " entry" : " entries")
 				+" from the fingerprint cache<br>\n");
 	
@@ -255,7 +253,7 @@ void pkgimport::Action(const string &cmd)
 	
 	if(m_volatileFiles.empty())
 	{
-		SendMsg("<font size=0 color=red>No index files detected. Unable to continue, cannot map files to internal locations.</font>");
+		SendChunk("<font size=0 color=red>No index files detected. Unable to continue, cannot map files to internal locations.</font>");
 		return;
 	}
 
@@ -269,7 +267,7 @@ void pkgimport::Action(const string &cmd)
 	
 	if(m_bErrAbort && m_nErrorCount>0)
 	{
-		SendMsg("Found errors during processing, aborting as requested.");
+		SendChunk("Found errors during processing, aborting as requested.");
 		return;
 	}
 	
@@ -284,7 +282,7 @@ void pkgimport::Action(const string &cmd)
 	
 	if(m_importMap.empty())
 	{
-		SendMsg("No appropriate files found in the _import directory.<br>\nDone.<br>\n");
+		SendChunk("No appropriate files found in the _import directory.<br>\nDone.<br>\n");
 		return;
 	}
 	
@@ -327,11 +325,7 @@ void pkgimport::Action(const string &cmd)
 					(uint64_t) it->second.mtime	);
 		}
 	}
-	if(cfh)
-	{
-		forceFclose(cfh);
-		cfh=NULL;
-	}
+	checkForceFclose(cfh);
 }
 
 #if 0
@@ -379,7 +373,7 @@ void pkgimport::_HandlePkgEntry(const tRemoteFileInfo &entry)
 	string sDestHead=sDest+".head";
 	const string &sFrom=hit->second.sPath;
 
-	SendMsg(string("<font color=green>HIT: ")+sFrom
+	SendChunk(string("<font color=green>HIT: ")+sFrom
 			+ "<br>\nDESTINATION: "+sDest+"</font><br>\n");
 
 	// linking and moving would shred them when the link leads to the same target
@@ -390,10 +384,10 @@ void pkgimport::_HandlePkgEntry(const tRemoteFileInfo &entry)
 	{
 		//cerr << "Same target file, ignoring."<<endl;
 		hit->second.bFileUsed=true;
-		SendMsg("<font color=orange>Same file exists</font><br>\n");
+		SendChunk("<font color=orange>Same file exists</font><br>\n");
 		if(0!=access(sDestHead.c_str(), F_OK))
 		{
-			SendMsg("<font color=orange>Header is missing, will recreate...</font><br>\n");
+			SendChunk("<font color=orange>Header is missing, will recreate...</font><br>\n");
 			goto gen_header;
 		}
 		return;
@@ -403,7 +397,7 @@ void pkgimport::_HandlePkgEntry(const tRemoteFileInfo &entry)
 	
 	if (!LinkOrCopy(sFrom, sDest))
 	{
-		SendMsg("<font color=red>ERROR: couldn't link or copy file.</font><br>\n");
+		SendChunk("<font color=red>ERROR: couldn't link or copy file.</font><br>\n");
 		return;
 	}
 
@@ -461,7 +455,7 @@ void pkgimport::_LoadKeyCache(const string & sFileName)
 	{
 		info.bFileUsed=false;
 		_getline
-		fpr.size=atol(sLine.c_str());
+		fpr.size=atoofft(sLine.c_str());
 		_getline
 		fpr.csType = (CSTYPES) atoi(sLine.c_str());
 		_getline
